import json
from .base import NgenicBase
from ..const import API_PATH

class Measurement(NgenicBase):
    def __init__(self, token, json, node, measurement_type):
        self._parentNode = node
        self._measurementType = measurement_type

        super(Measurement, self).__init__(token, json)

    def getType(self):
        """Get the measurement type"""
        return self._measurementType



import json
from .base import NgenicBase
from ..const import API_PATH

class Room(NgenicBase):
    def __init__(self, token, json, tune):
        self._parentTune = tune

        super(Room, self).__init__(token, json)

    def update(self):
        """Update this room with its current values"""
        roomUuid = self["uuid"]

        url = API_PATH["rooms"].format(tuneUuid=self._parentTune.uuid(), roomUuid=roomUuid)
        self._put(url, data=self.json())



from setuptools import setup, find_packages

with open("README.md", 'r') as f:
    long_description = f.read()

setup(
   name='ngenicpy',
   version='0.1.0',
   description='Python package for simple access to Ngenic Tune API',
   license="MIT",
   long_description=long_description,
   long_description_content_type="text/markdown",
   author='Simon Falkman',
   author_email='sfalkman@gmail.com',
   url="https://github.com/sfalkman/ngenic-py",
   packages=find_packages(exclude=["tests"]),
   install_requires=['requests'],
   classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import json
from .base import NgenicBase
from ..const import API_PATH

class NodeStatus(NgenicBase):
    def __init__(self, token, json, node):
        self._parentNode = node

        super(NodeStatus, self).__init__(token, json)

    def getBatteryPercentage(self):
        if self["maxBattery"] == 0:
            # not using batteries
            return 100

        return int((self["battery"] / self["maxBattery"]) * 100)

    def getRadioSignalPercentage(self):
        if self["maxRadioStatus"] == 0:
            # shouldn't happen as of now (always maxRadioStatus is always 4)
            return 100

        return int((self["radioStatus"] / self["maxRadioStatus"]) * 100)
